==> Horde_Mime_Viewer-1.0.9.tgz: Horde_Mime_Viewer-1.0.9/lib/Horde/Mime/Viewer/Translation.php <==
<?php
/**
 * @package Mime_Viewer
 *
 * Copyright 2010-2012 Horde LLC (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (LGPL). If you
 * did not receive this file, see http://www.horde.org/licenses/lgpl21.
 */

/**
 * Horde_Mime_Viewer_Translation is the translation wrapper class for Horde_Mime_Viewer.
 *
 * @author  Jan Schneider <jan@horde.org>
 * @package Mime_Viewer
 */
class Horde_Mime_Viewer_Translation extends Horde_Translation
{
    /**
     * Returns the translation of a message.
     *
     * @var string $message  The string to translate.
     *
     * @return string  The string translation, or the original string if no
     *                 translation exists.
     */
    static public function t($message)
    {
        self::$_domain = 'Horde_Mime_Viewer';
        self::$_directory = '@data_dir@' == '@'.'data_dir'.'@' ? dirname(__FILE__) . '/../../../../locale' : '@data_dir@/Horde_Mime_Viewer/locale';
        return parent::t($message);
    }

    /**
     * Returns the plural translation of a message.
     *
     * @param string $singular  The singular version to translate.
     * @param string $plural    The plural version to translate.
     * @param integer $number   The number that determines singular vs. plural.
     *
     * @return string  The string translation, or the original string if no
     *                 translation exists.
     */
    static public function ngettext($singular, $plural, $number)
    {
        self::$_domain = 'Horde_Mime_Viewer';
        self::$_directory = '@data_dir@' == '@'.'data_dir'.'@' ? dirname(__FILE__) . '/../../../../locale' : '@data_dir@/Horde_Mime_Viewer/locale';
        return parent::ngettext($singular, $plural, $number);
    }
}

==> Horde_Mime_Viewer-2.0.1.tgz: Horde_Mime_Viewer-2.0.1/lib/Horde/Mime/Viewer/Translation.php <==
<?php
/**
 * @package Mime_Viewer
 *
 * Copyright 2010-2012 Horde LLC (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (LGPL). If you
 * did not receive this file, see http://www.horde.org/licenses/lgpl21.
 */

/**
 * Horde_Mime_Viewer_Translation is the translation wrapper class for Horde_Mime_Viewer.
 *
 * @author  Jan Schneider <jan@horde.org>
 * @package Mime_Viewer
 */
class Horde_Mime_Viewer_Translation extends Horde_Translation
{
    /**
     * Returns the translation of a message.
     *
     * @var string $message  The string to translate.
     *
     * @return string  The string translation, or the original string if no
     *                 translation exists.
     */
    static public function t($message)
    {
        self::$_domain = 'Horde_Mime_Viewer';
        self::$_directory = '@data_dir@' == '@'.'data_dir'.'@' ? __DIR__ . '/../../../../locale' : '@data_dir@/Horde_Mime_Viewer/locale';
        return parent::t($message);
    }

    /**
     * Returns the plural translation of a message.
     *
     * @param string $singular  The singular version to translate.
     * @param string $plural    The plural version to translate.
     * @param integer $number   The number that determines singular vs. plural.
     *
     * @return string  The string translation, or the original string if no
     *                 translation exists.
     */
    static public function ngettext($singular, $plural, $number)
    {
        self::$_domain = 'Horde_Mime_Viewer';
        self::$_directory = '@data_dir@' == '@'.'data_dir'.'@' ? __DIR__ . '/../../../../locale' : '@data_dir@/Horde_Mime_Viewer/locale';
        return parent::ngettext($singular, $plural, $number);
    }
}
